<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Http\Requests\ApplyCouponRequest;
use App\Http\Requests\VoucherRequest;
use App\Http\Resources\CouponResource;
use App\Repositories\CouponCollectRepository;
use App\Repositories\CouponRepository;
use Illuminate\Http\Request;

class CouponController extends Controller
{
    /**
     * get available coupon
     */
    public function index()
    {
        $coupons = CouponRepository::query()->Active()->isValid()->get();

        return $this->json('available coupons', [
            'coupons' => CouponResource::collection($coupons),
        ]);
    }

    /**
     * collect voucher
     * */
    public function store(VoucherRequest $request)
    {
        $hasExistCoupon = CouponCollectRepository::hasExistCoupon($request);

        if ($hasExistCoupon) {
            return $this->json('Voucher already collected');
        }

        $coupon = CouponCollectRepository::storeByRequest($request);

        return $this->json('Voucher collected successfully', [
            'coupon' => CouponResource::make($coupon->coupon),
        ]);
    }

    /**
     * get collected vouchers
     *
     * @param  VoucherRequest  $request
     * */
    public function collectedVouchers()
    {

        // get collected vouchers from repository
        $coupons = CouponRepository::getCollectedCoupons();

        return $this->json('available collected vouchers', [
            'coupons' => CouponResource::collection($coupons),
        ]);
    }
}
